@@ -487,9 +487,9 @@ def create_job(
             f.seek(0)
             build_info = json.load(f)
             if not version:
-                version = build_info["version"]
+                version = build_info.get("version", "N/A")
         except Exception as e:
-            abort(f"Could not load buildinfo.json from {s3_path}. Was the path correct?")
+            secho(f"Could not load buildinfo.json from {s3_path}. Was the path correct? Error: {e}", fg="red")
 
     all_nodes = find_nodes(ctx)
     if node_id:
