@@ -31,9 +31,7 @@ class Profile:
     profile_name = None
     content = None
 
-    def __init__(
-        self, profile_name: Optional[str] = None, content: Optional[Dict] = None
-    ) -> None:
+    def __init__(self, profile_name: Optional[str] = None, content: Optional[Dict] = None) -> None:
         if profile_name:
             self.profile_name = profile_name
             self.content = config.get("profiles")[self.profile_name]
@@ -54,13 +52,14 @@ class Profile:
             if self.profile_name:
                 save_config()
 
+
 class ServiceSession(requests.Session):
     """
     A wrapped requests session object with base_url and endpoints
     from kamo service api's
     """
 
-    def __init__(self, domain = None, api_key = None, profile=None, tenant=None, *args, **kwargs):
+    def __init__(self, domain=None, api_key=None, profile=None, tenant=None, *args, **kwargs):
         super(ServiceSession, self).__init__(*args, **kwargs)
         # retry idempotent methods up to 5 times
         # if not environ.get("KAMO_DISABLE_RETRY"):
@@ -99,9 +98,7 @@ class ServiceSession(requests.Session):
                 list(config.get("profiles")),
             )
             if self.profile_name not in config.get("profiles"):
-                raise InvalidProfile(
-                    "The config profile (%s) could not be found" % profile
-                )
+                raise InvalidProfile("The config profile (%s) could not be found" % profile)
             self.profile = Profile(self.profile_name)
         else:
             # if there is no profile there needs to be configuration set in the
@@ -109,9 +106,7 @@ class ServiceSession(requests.Session):
             # backed up by disk.
             api_key = api_key or environ.get("KAMO_API_KEY")
             if not api_key:
-                raise InvalidProfile(
-                    "No profile specified and KAMO_API_KEY not set in environment"
-                )
+                raise InvalidProfile("No profile specified and KAMO_API_KEY not set in environment")
             domain = domain or environ.get("KAMO_DOMAIN")
             self.profile = Profile(content={"api_key": api_key, "domain": domain, "tenant": ""})
 
@@ -135,7 +130,6 @@ class ServiceSession(requests.Session):
         if api_key:
             self.api_key = api_key
 
-
         if environ.get("KAMO_API_KEY"):
             log.info("Overriding api key from environment")
             self.api_key = environ["KAMO_API_KEY"]
@@ -167,7 +161,9 @@ class ServiceSession(requests.Session):
             log.warning("Error fetching root info")
         if self.api_key:
             try:
-                self.token = get_access_token(self.api_key, self.root_info["config"]["auth_client_id"], self.root_info["config"]["auth_url"])
+                self.token = get_access_token(
+                    self.api_key, self.root_info["config"]["auth_client_id"], self.root_info["config"]["auth_url"]
+                )
                 self.headers["Authorization"] = "Bearer {}".format(self.token)
             except Exception as ex:
                 log.warning("Error fetching access token: %s", str(ex))
@@ -213,10 +209,7 @@ class ServiceSession(requests.Session):
             self.headers["Content-Type"] = old_content_type
 
         # Manage response from the server
-        log.info(
-            "%s %s returned %s in %.3f sec"
-            % (method.upper(), args[0], response.status_code, diff)
-        )
+        log.info("%s %s returned %s in %.3f sec" % (method.upper(), args[0], response.status_code, diff))
 
         check_resp_error(response)
         return response
@@ -245,29 +238,19 @@ class ServiceSession(requests.Session):
         return self._do_request("delete", True, *args, **kw)
 
     def fetch_root_info(self) -> Dict:
-        log.debug(
-            "fetch_root_info(): domain: {0}, headers: {1}".format(
-                self.domain, self.headers
-            )
-        )
+        log.debug("fetch_root_info(): domain: {0}, headers: {1}".format(self.domain, self.headers))
         root_url = self.get_url("kamo")
         try:
             r = requests.get(root_url, timeout=3.0, headers=self.headers)
         except requests.exceptions.ConnectionError as ex:
-            raise ServerError(
-                f"Could not reach server {root_url} ({ex})"
-            ) from None
+            raise ServerError(f"Could not reach server {root_url} ({ex})") from None
         except requests.exceptions.ReadTimeout as ex:
-            raise ServerError(
-                f"Could not reach server {root_url} ({ex})"
-            ) from None
+            raise ServerError(f"Could not reach server {root_url} ({ex})") from None
 
         r.raise_for_status()
 
         if "application/json" not in r.headers["Content-Type"]:
-            raise ServerError(
-                "Unexpected response: %s" % r.text, url=root_url
-            ) from None
+            raise ServerError("Unexpected response: %s" % r.text, url=root_url) from None
         ret = r.json()
         self.root_info = ret
         return ret
